@@ -336,6 +336,13 @@ class InvoiceItem(MultiCurrencyPrice):
     def profit_subtotal_uah(self):
         return self.subtotal_with_discount - self.wholesale_subtotal_uah
 
+    @property
+    def printable_qty(self):
+        if hasattr(self.product, 'format_qty'):
+            return self.product.format_qty(self.qty)
+
+        return self.qty
+
     def render(self):
         return render_to_string('invoices/item.html', {'object': self})
 
@@ -379,8 +386,8 @@ class Arrival(Invoice):
             item.product.subtract_stock(item.qty)
 
     class Meta:
-        verbose_name = _('Arrival')
-        verbose_name_plural = _('Arrivals')
+        verbose_name = _('Arrival invoice')
+        verbose_name_plural = _('Arrival invoices')
 
 
 class ArrivalItem(InvoiceItem):
@@ -440,8 +447,8 @@ class Sale(Invoice):
         return totals
 
     class Meta:
-        verbose_name = _('Sale')
-        verbose_name_plural = _('Sales')
+        verbose_name = _('Sales invoice')
+        verbose_name_plural = _('Sales invoices')
 
 
 class SaleItem(InvoiceItem):
